<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border};


class Quiety_App_Button extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-app-button';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @return string Widget title.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_title() {
		return __( 'Quiety App Download Button', 'quiety-core' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @return string Widget icon.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_icon() {
		return 'eicon-download-button';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the icon box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	/**
	 * Get button sizes.
	 *
	 * Retrieve an array of button sizes for the button widget.
	 *
	 * @return array An array containing button sizes.
	 * @since 1.0.0
	 * @access public
	 * @static
	 *
	 */
	public static function get_button_sizes() {
		return [
			'btn-xs' => __( 'Extra Small', 'quiety-core' ),
			'btn-sm' => __( 'Small', 'quiety-core' ),
			'btn-md' => __( 'Medium', 'quiety-core' ),
			'btn-lg' => __( 'Large', 'quiety-core' ),
			'btn-xl' => __( 'Extra Large', 'quiety-core' ),
		];
	}

	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section( 'section_button', [
			'label' => __( 'Button', 'quiety-core' ),
		] );

		$this->add_responsive_control(
			'button_display',
			[
				'label' => __( 'Display', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'inline' => [
						'title' => __( 'Inline', 'plugin-domain' ),
						'icon' => 'eicon-ellipsis-h',
					],
					'block' => [
						'title' => __( 'Block', 'plugin-domain' ),
						'icon' => 'eicon-ellipsis-v',
					],
				],
				'default' => 'inline',
				'toggle' => true,
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control( 'text', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( 'Button Text', 'quiety-core' ),
		] );

		$repeater->add_control( 'tagline', [
			'label'       => __( 'Tagline', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( 'Button Text', 'quiety-core' ),
		] );

		$repeater->add_control( 'link', [
			'label'       => __( 'Link', 'quiety-core' ),
			'type'        => Controls_Manager::URL,
			'placeholder' => 'http://your-link.com',
			'default'     => [
				'url' => '#',
			],
		] );

		$repeater->add_control( 'button_style', [
			'label'   => __( 'Button Style', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'btn-default',
			'options' => [
				'btn-default' => __( 'Fill', 'quiety-core' ),
				'btn-outline' => __( 'Outline', 'quiety-core' ),
			],
		] );

		$repeater->add_control( 'selected_icon', [
			'label'   => __( 'Icon', 'quiety-core' ),
			'type'    => Controls_Manager::ICONS,
			'default' => [
				'value'   => 'fas fa-arrow-right',
				'library' => 'solid',
			],
		] );

		$repeater->add_control( 'icon_align', [
			'label'     => __( 'Icon Position', 'quiety-core' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'left',
			'options'   => [
				'left'  => __( 'Before', 'quiety-core' ),
				'right' => __( 'After', 'quiety-core' ),
			],
			'condition' => [
				'selected_icon!' => '',
			],
		] );

		$repeater->add_control( 'icon_indent', [
			'label'     => __( 'Icon Spacing', 'quiety-core' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'max' => 50,
				],
			],
			'condition' => [
				'selected_icon!' => '',
			],
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn .elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn .elementor-align-icon-left'  => 'margin-right: {{SIZE}}{{UNIT}};',
			],
		] );

		$repeater->add_control(
			'custom_style',
			[
				'label' => __( 'Override Global Style?', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'your-plugin' ),
				'label_off' => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$repeater->start_controls_tabs( 'tabs_button_style', ['condition' => ['custom_style' => 'yes']]);

		$repeater->start_controls_tab( 'tab_button_normal', [
			'label' => __( 'Normal', 'quiety-core' ),
		] );

		$repeater->add_control( 'button_text_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn' => 'color: {{VALUE}};',
			],
		] );

//		$repeater->add_control( 'background_color', [
//			'label'     => __( 'Background Color', 'quiety-core' ),
//			'type'      => Controls_Manager::COLOR,
//			'selectors' => [
//				'{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn' => 'background-color: {{VALUE}};',
//			],
//		] );

		$repeater->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background_color',
				'label' => esc_html__( 'Background', 'plugin-name' ),
				'types' => [ 'classic', 'gradient'],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn' => 'background: {{VALUE}};',
				],
			]
		);


		$repeater->add_group_control( Group_Control_Border::get_type(), [
			'name'     => 'border',
			'label'    => __( 'Border', 'quiety-core' ),
			'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn',
		] );

		$repeater->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'box_shadow',
			'label'    => __( 'Box Shadow', 'quiety-core' ),
			'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn',
		] );

		$repeater->end_controls_tab();

		$repeater->start_controls_tab( 'tab_button_hover', [
			'label' => __( 'Hover', 'quiety-core' ),
		] );

		$repeater->add_control( 'hover_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn:hover' => 'color: {{VALUE}};',
			],
		] );


		$repeater->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background_color_hover',
				'label' => esc_html__( 'Background', 'plugin-name' ),
				'types' => [ 'classic', 'gradient'],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn:hover' => 'background: {{VALUE}};',
				],
			]
		);

		$repeater->add_group_control( Group_Control_Border::get_type(), [
			'name'     => 'border_hover',
			'label'    => __( 'Border', 'quiety-core' ),
			'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn:hover'
		] );

		$repeater->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'box_shadow_hover',
			'label'    => __( 'Box Shadow', 'quiety-core' ),
			'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}.tt-app-btn:hover',
		] );

		$repeater->end_controls_tab();
		$repeater->end_controls_tabs();

		$this->add_control( 'button_list', [
			'label'       => __( 'Button List', 'quiety-core' ),
			'type'        => \Elementor\Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'tagline' => __( 'Available on the ', 'quiety-core' ),
					'text'   => __( 'App Store', 'quiety-core' ),
					'selected_icon' => [
						'value'   => 'fab fa-apple',
						'library' => 'brands',
					]
				],
				[
					'tagline' => __( 'Available on the ', 'quiety-core' ),
					'text'   => __( 'Play Store', 'quiety-core' ),
					'selected_icon' => [
						'value'   => 'fab fa-google-play',
						'library' => 'brands',
					]
				],
				[
					'tagline' => __( 'Available on the ', 'quiety-core' ),
					'text'   => __( 'Microsoft Store', 'quiety-core' ),
					'selected_icon' => [
						'value'   => 'fab fa-windows',
						'library' => 'brands',
					]
				],
			],
			'title_field' => '{{{ text }}}',
		] );


		$this->add_responsive_control( 'align', [
			'label'        => __( 'Alignment', 'quiety-core' ),
			'type'         => Controls_Manager::CHOOSE,
			'options'      => [
				'left'    => [
					'title' => __( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'center'  => [
					'title' => __( 'Center', 'quiety-core' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'   => [
					'title' => __( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],
				'justify' => [
					'title' => __( 'Justified', 'quiety-core' ),
					'icon'  => 'fa fa-align-justify',
				],
			],
			'prefix_class' => 'elementor%s-align-',
			'default'      => '',
		] );

		$this->add_control( 'view', [
			'label'   => __( 'View', 'quiety-core' ),
			'type'    => Controls_Manager::HIDDEN,
			'default' => 'traditional',
		] );

		$this->end_controls_section();

		// Style Section
		//======================

		$this->start_controls_section( 'section_style', [
			'label' => __( 'Button', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control(
			'button_space',
			[
				'label' => __( 'Spacing', 'plugin-domain' ),
				'type' => Controls_Manager::SLIDER,
//				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => -10,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 15,
				],
				'selectors' => [
					'{{WRAPPER}} .tt-btn-wrapper.inline .tt-app-btn:not(:last-child)' => 'margin-right: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .tt-btn-wrapper.block .tt-app-btn:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'typography',
            'label'    => __( 'Title Typography', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-app-btn .tt-btn-text',
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'tagline_typo',
            'label'    => __( 'Tagline Typography', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-app-btn .btn-tagline',
        ] );

		$this->add_control( 'border_radius', [
			'label'      => __( 'Border Radius', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors'  => [
				'{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .tt-app-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );


		$this->add_control( 'btn_padding', [
			'label'      => __( 'Padding', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors'  => [
				'{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .tt-app-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );


		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab( 'tab_button_normal', [
			'label' => __( 'Normal', 'quiety-core' ),
		] );

		$this->add_control( 'button_text_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .tt-app-btn' => 'color: {{VALUE}};',
			],
		] );

//		$this->add_control( 'background_color', [
//			'label'     => __( 'Background Color', 'quiety-core' ),
//			'type'      => Controls_Manager::COLOR,
//			'selectors' => [
//				'{{WRAPPER}} .tt-app-btn' => 'background-color: {{VALUE}};',
//			],
//		] );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background_color',
				'label' => esc_html__( 'Background', 'plugin-name' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .tt-app-btn',
			]
		);


		$this->add_group_control( Group_Control_Border::get_type(), [
			'name'     => 'border',
			'label'    => __( 'Border', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-app-btn',
		] );

		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'box_shadow',
			'label'    => __( 'Box Shadow', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-app-btn',
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'tab_button_hover', [
			'label' => __( 'Hover', 'quiety-core' ),
		] );

		$this->add_control( 'hover_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-app-btn:hover' => 'color: {{VALUE}};',
			],
		] );

//		$this->add_control( 'background_color_hover', [
//			'label'     => __( 'Background Color', 'quiety-core' ),
//			'type'      => Controls_Manager::COLOR,
//			'selectors' => [
//				'{{WRAPPER}} .tt-app-btn:hover' => 'background-color: {{VALUE}};',
//			],
//		] );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background_color_hover',
				'label' => esc_html__( 'Background', 'plugin-name' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .tt-app-btn:hover',
			]
		);

		$this->add_group_control( Group_Control_Border::get_type(), [
			'name'     => 'border_hover',
			'label'    => __( 'Border', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-app-btn:hover'
		] );

		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'box_shadow_hover',
			'label'    => __( 'Box Shadow', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-app-btn:hover',
		] );

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings    = $this->get_settings_for_display();
//		$button_type = $settings['button_size'];

		$settings = $this->get_settings_for_display();
		$this->add_render_attribute( 'content-wrapper', 'class', 'tt-btn-content-wrapper' );
		$this->add_render_attribute( 'icon-align', 'class', 'tt-btn-icon' );
		$this->add_render_attribute( 'text', 'class', 'tt-btn-text' );
		$this->add_render_attribute('wrapper',
			[
				'class' => ['tt-btn-wrapper', $settings['button_display'] ]
			]
		);

		?>
		<div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
			<?php if ( ! empty( $settings['button_list'] ) ) : ?>
				<?php foreach ( $settings['button_list'] as $item ) :
					$this->add_render_attribute( 'icon-align', 'class', 'elementor-align-icon-' . $item['icon_align'] );
					?>

					<a href="<?php echo esc_url( $item['link']['url'] ); ?>" class="tt-app-btn elementor-repeater-item-<?php echo $item['_id']; ?> <?php echo esc_attr($item['button_style']); ?>">
						<span <?php echo $this->get_render_attribute_string( 'content-wrapper' ); ?>>
							<?php if ( ! empty( $item['selected_icon'] ) ) : ?>
								<span <?php echo $this->get_render_attribute_string( 'icon-align' ); ?>>
									<?php if ( ! empty( $item['selected_icon'] ) ) : ?>
										<?php \Elementor\Icons_Manager::render_icon( $item['selected_icon'], [ 'aria-hidden' => 'true' ] ); ?>
									<?php endif; ?>
								</span>
							<?php endif; ?>
							<span class="text-wrapper">
								<span class="btn-tagline">
									<?php echo esc_html( $item['tagline'] ); ?>
								</span>
								<span <?php echo $this->get_render_attribute_string( 'text' ); ?>><?php echo $item['text']; ?></span>
							</span>
						</span>
					</a>

				<?php endforeach; ?>
			<?php endif; ?>
		</div>
		<?php
	}
}