<?php
namespace Quiety\Widgets;

use Elementor\Icons_Manager;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;

class Quiety_Dual_Button extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name()
	{
		return 'tt-dual-button';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @return string Widget title.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_title() {
		return __('Quiety Dual Button', 'quiety-core');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @return string Widget icon.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_icon()
	{
		return 'eicon-dual-button';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the icon box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories()
	{
		return ['tt-elements'];
	}


	/**
	 * The keywords for search.
	 *
	 * @return array
	 */
	public function get_keywords() {
		return [ 'button', 'call to action', 'decent element', 'btn' ];
	}


	/**
	 * Get button sizes.
	 *
	 * Retrieve an array of button sizes for the button widget.
	 *
	 * @return array An array containing button sizes.
	 * @since 1.0.0
	 * @access public
	 * @static
	 *
	 */
	public static function get_button_sizes()
	{
		return [
			'btn-xs' => __('Extra Small', 'quiety-core'),
			'btn-sm' => __('Small', 'quiety-core'),
			'btn-md' => __('Medium', 'quiety-core'),
			'btn-lg' => __('Large', 'quiety-core'),
			'btn-xl' => __('Extra Large', 'quiety-core'),
		];
	}

	/**
	 * Add controls.
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'second_button_section',
			[
				'label' => __( 'General Settings', 'quiety-core' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_responsive_control(
			'button_align',
			[
				'label' => __( 'Alignment', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'quiety-core' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'quiety-core' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'quiety-core' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => 'left',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .tt-button-container' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'size',
			[
				'label' => esc_html__( 'Size', 'quiety-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-md',
				'options' => $this->get_button_sizes(),
				'style_transfer' => true,
			]
		);

		$this->add_responsive_control( 'space_between_button', [
			'label'           => __( 'Space Between Buttons', 'quiety-core' ),
			'type'            => Controls_Manager::SLIDER,
			'range'           => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => 15,
			],
			'selectors'       => [
				'{{WRAPPER}} .tt-button-primary' => 'margin-right: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} .tt-block .tt-button-primary' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
			'separator' => 'after'
		] );

		$this->end_controls_section();


		$this->start_controls_section(
			'button_section',
			[
				'label' => __( 'Dual Button', 'quiety-core' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->start_controls_tabs( 'tabs_dual_button' );

		$this->start_controls_tab(
			'tab_button_primary',
			[
				'label' => __('Primary', 'quiety-core'),
			]
		);

		$this->add_control(
			'button_label',
			[
				'label' => __( 'Text', 'quiety-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Click Here', 'quiety-core' ),
				'placeholder' => __( 'Type your button title here', 'quiety-core' ),
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'button_link',
			[
				'label' => __( 'Link', 'quiety-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
				'default' => [
					'url' => '#',
				],
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'button_icon_options',
			[
				'label' => __( 'Icons', 'quiety-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'selected_icon',
			[
				'label' => esc_html__( 'Icon', 'quiety-core' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'skin' => 'inline',
				'label_block' => false,
			]
		);

		$this->add_control(
			'icon_align',
			[
				'label' => esc_html__( 'Icon Position', 'quiety-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left' => esc_html__( 'Before', 'quiety-core' ),
					'right' => esc_html__( 'After', 'quiety-core' ),
				],
				'condition' => [
					'selected_icon[value]!' => '',
				],
			]
		);

		$this->add_control(
			'icon_indent',
			[
				'label' => esc_html__( 'Icon Spacing', 'quiety-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tt-btn-one .tt-btn__align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .tt-btn-one .tt-btn__align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'button_shape',
			[
				'label' => __('Shape', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-round',
				'options' => [
					'btn-square' => __('Square', 'quiety-core'),
					'btn-round' => __('Round', 'quiety-core'),
					'btn-circle' => __('Circle', 'quiety-core'),
				],
			]
		);

		$this->add_control(
			'button_style',
			[
				'label' => __('Shape', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-default',
				'options' => [
					'btn-default' => __('Default', 'quiety-core'),
					'btn-outline' => __('Outline', 'quiety-core'),
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_secondary',
			[
				'label' => __('Secondary', 'quiety-core'),
			]
		);

		$this->add_control(
			'button_type',
			[
				'label' => __('Shape', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'button',
				'options' => [
					'button' => __('Simple Button', 'quiety-core'),
					'popup_video' => __('Popup Video Button', 'quiety-core'),
				],
			]
		);

		$this->add_control(
			'sec_button_label',
			[
				'label' => __( 'Text', 'quiety-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Click Here', 'quiety-core' ),
				'placeholder' => __( 'Type your button title here', 'quiety-core' ),
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'sec_button_link',
			[
				'label' => __( 'Link', 'quiety-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
				'default' => [
					'url' => '#',
				],
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'sec_button_icon_options',
			[
				'label' => __( 'Icons', 'quiety-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'sec_selected_icon',
			[
				'label' => esc_html__( 'Icon', 'quiety-core' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'sec_icon',
				'skin' => 'inline',
				'label_block' => false,
			]
		);

		$this->add_control(
			'sec_icon_align',
			[
				'label' => esc_html__( 'Icon Position', 'quiety-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left' => esc_html__( 'Before', 'quiety-core' ),
					'right' => esc_html__( 'After', 'quiety-core' ),
				],
				'condition' => [
					'sec_selected_icon[value]!' => '',
				],
			]
		);

		$this->add_control(
			'sec_icon_indent',
			[
				'label' => esc_html__( 'Icon Spacing', 'quiety-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tt-btn-two .tt-btn__align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .tt-btn-two .tt-btn__align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'sec_button_shape',
			[
				'label' => __('Shape', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-round',
				'options' => [
					'btn-square' => __('Square', 'quiety-core'),
					'btn-round' => __('Round', 'quiety-core'),
					'btn-circle' => __('Circle', 'quiety-core'),
				],
			]
		);

		$this->add_control(
			'sec_button_style',
			[
				'label' => __('Shape', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-outline',
				'options' => [
					'btn-default' => __('Default', 'quiety-core'),
					'btn-outline' => __('Outline', 'quiety-core'),
				],
			]
		);


		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_responsive_control(
			'button_layout',
			[
				'label' => __( 'Layout', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'tt-inline' => [
						'title' => __( 'Inline', 'quiety-core' ),
						'icon' => 'eicon-navigation-horizontal',
					],
					'tt-block' => [
						'title' => __( 'Block', 'quiety-core' ),
						'icon' => 'eicon-navigation-vertical',
					],
				],
				'default' => 'tt-inline',
			]
		);

		$this->end_controls_section();

		// Button Primary Style Section
		//=====================================
		$this->start_controls_section(
			'button_primary_style_section',
			[
				'label' => __( 'Button', 'quiety-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'label' => __( 'Typography', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-tt-btn-one',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'text_shadow',
				'selector' => '{{WRAPPER}} .tt-tt-btn-one',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-btn-one' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'text_padding',
			[
				'label' => esc_html__( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .tt-btn-one' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => esc_html__( 'Normal', 'quiety-core' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => esc_html__( 'Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tt-btn-one' => 'fill: {{VALUE}}; color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => esc_html__( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .tt-btn-one',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .tt-btn-one',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .tt-btn-one',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => esc_html__( 'Hover', 'quiety-core' ),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label' => esc_html__( 'Text Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn-one:hover, {{WRAPPER}} .tt-btn-one:focus' => 'color: {{VALUE}};',
					'{{WRAPPER}} .tt-btn-one:hover svg, {{WRAPPER}} .tt-btn-one:focus svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_background_hover',
				'label' => esc_html__( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .tt-btn-one:hover, {{WRAPPER}} .tt-btn-one:focus',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
			]
		);


		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border_hover',
				'selector' => '{{WRAPPER}} .tt-btn-one:hover',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow_hover',
				'selector' => '{{WRAPPER}} .tt-btn-one:hover',
			]
		);

		$this->add_control(
			'hover_animation',
			[
				'label' => esc_html__( 'Hover Animation', 'quiety-core' ),
				'type' => Controls_Manager::HOVER_ANIMATION,
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		// Secondary Button Style
		//============================
		$this->start_controls_section(
			'button_secondary_style_section',
			[
				'label' => __( 'Secondary Button', 'quiety-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'button_type' => 'button'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sec_button_typography',
				'label' => __( 'Typography', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .btn-two',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'sec_text_shadow',
				'selector' => '{{WRAPPER}} .btn-two',
			]
		);

		$this->add_control(
			'sec_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-btn-two' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'sec_text_padding',
			[
				'label' => esc_html__( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .tt-btn-two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'sec_tabs_button_style' );

		$this->start_controls_tab(
			'sec_tab_button_normal',
			[
				'label' => esc_html__( 'Normal', 'quiety-core' ),
			]
		);

		$this->add_control(
			'sec_button_text_color',
			[
				'label' => esc_html__( 'Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tt-btn-two' => 'fill: {{VALUE}}; color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'sec_background',
				'label' => esc_html__( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .tt-btn-two',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sec_border',
				'selector' => '{{WRAPPER}} .tt-btn-two',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'sec_button_box_shadow',
				'selector' => '{{WRAPPER}} .tt-btn-two',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'sec_tab_button_hover',
			[
				'label' => esc_html__( 'Hover', 'quiety-core' ),
			]
		);

		$this->add_control(
			'sec_hover_color',
			[
				'label' => esc_html__( 'Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn-two:hover, {{WRAPPER}} .tt-btn-two:focus' => 'color: {{VALUE}};',
					'{{WRAPPER}} .tt-btn-two:hover svg, {{WRAPPER}} .tt-btn-two:focus svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'sec_button_background_hover',
				'label' => esc_html__( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .tt-btn-two:hover, {{WRAPPER}} .tt-btn-two:focus',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sec_border_hover',
				'selector' => '{{WRAPPER}} .tt-btn-two:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'sec_button_box_shadow_hover',
				'selector' => '{{WRAPPER}} .tt-btn-two:hover',
			]
		);

		$this->add_control(
			'sec_hover_animation',
			[
				'label' => esc_html__( 'Hover Animation', 'quiety-core' ),
				'type' => Controls_Manager::HOVER_ANIMATION,
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->end_controls_section();

		// Video Button Style
		//=======================
		$this->start_controls_section(
			'video_button_style',
			[
				'label' => __( 'Popup Video Button', 'quiety-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'button_type' => 'popup_video'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'video_button_typography',
				'label' => __( 'Typography', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .play-button',
			]
		);

		$this->add_control(
			'video_border_radius',
			[
				'label' => esc_html__( 'Icon Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .play-button i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'video_text_padding',
			[
				'label' => esc_html__( 'Icon Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .play-button i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->start_controls_tabs( 'tabs_video_style' );

		$this->start_controls_tab(
			'tab_button_video_normal',
			[
				'label' => esc_html__( 'Normal', 'quiety-core' ),
			]
		);

		$this->add_control(
			'video_button_color',
			[
				'label' => esc_html__( 'Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'video_button_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'play_button_background',
				'label' => esc_html__( 'Icon Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .play-button i',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'play_button_border',
				'selector' => '{{WRAPPER}} .play-button i',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'video_button_box_shadow',
				'selector' => '{{WRAPPER}} .play-button i ',
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_video_button_hover',
			[
				'label' => esc_html__( 'Hover', 'quiety-core' ),
			]
		);

		$this->add_control(
			'video_button_hover_color',
			[
				'label' => esc_html__( 'Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button:hover, {{WRAPPER}} .play-button:focus' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'video_button_hover_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button:hover i, {{WRAPPER}} .play-button:focus i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'play_button_background_hover',
				'label' => esc_html__( 'Icon Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .play-button:hover i, {{WRAPPER}} .play-button:focus i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'play_button_border_hover',
				'selector' => '{{WRAPPER}} .play-button:hover i',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'video_button_hover_box_shadow',
				'selector' => '{{WRAPPER}} .play-button:hover i',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$migration_allowed = Icons_Manager::is_migration_allowed();

		$migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
		$is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();

		if ( ! $is_new && empty( $settings['icon_align'] ) ) {
			$settings['icon_align'] = $this->get_settings( 'icon_align' );
		}

		if ( ! $is_new && empty( $settings['sec_icon_align'] ) ) {
			$settings['sec_icon_align'] = $this->get_settings( 'sec_icon_align' );
		}

		if ( ! empty( $settings['button_link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['button_link'] );
		}

		if ( ! empty( $settings['sec_button_link']['url'] ) ) {
			$this->add_link_attributes( 'buttontwo', $settings['sec_button_link'] );
		}

		// Video Button
		if ( ! empty( $settings['sec_button_link']['url'] ) ) {
			$this->add_link_attributes( 'video', $settings['sec_button_link'] );
		}

		/**
		 * Button
		 */
		$this->add_render_attribute( 'button', 'class', ['tt-btn tt-btn-one', $settings['button_style'] ] );
		$this->add_render_attribute( 'video', 'class', 'play-button btn-fill'  );

		/**
		 * Button Size Class
		 */
		if ( ! empty ( $settings['size'] ) ) {
			$this->add_render_attribute( 'button', 'class', $settings['size'] );
		}

		$this->add_render_attribute( 'buttontwo', 'class', ['tt-btn tt-btn-two', $settings['sec_button_style'] ] );

		/**
		 * Button Size Class
		 */
		if ( ! empty ( $settings['size'] ) ) {
			$this->add_render_attribute( 'buttontwo', 'class', $settings['size'] );
		}


		/**
		 * Extra Css Classes
		 */
		if ( ! empty( $settings['button_class'] ) ) {
			$this->add_render_attribute( 'button', 'class', $settings['button_class'] );
		}

		if ( ! empty( $settings['button_id'] ) ) {
			$this->add_render_attribute( 'button', 'id', $settings['button_id'] );
		}
		$this->add_render_attribute( [
		     'icon-align' => [
		         'class' => [
		             'tt-btn__icon',
		             'tt-btn__align-icon-' . $settings['icon_align'],
		         ],
		     ],
		     'text' => [
		         'class' => 'tt-btn__text',
		     ],
		 ] );

		$this->add_render_attribute( [
			 'sec_icon_align' => [
				 'class' => [
					 'tt-btn__icon',
					 'tt-btn__align-icon-' . $settings['sec_icon_align'],
				 ],
			 ],
			 'text' => [
				 'class' => 'tt-btn__text',
			 ],
		 ] );

		$this->add_render_attribute( 'button_label', 'class', 'tt-btn__text' );
		$this->add_inline_editing_attributes( 'button_label', 'none' );

		$this->add_render_attribute( 'sec_button_label', 'class', 'tt-btn__text' );
		$this->add_inline_editing_attributes( 'sec_button_label', 'none' );

		?>

		<div class="tt-button-container <?php echo esc_attr( $settings['button_layout'] ); ?>">

			<?php if ( ! empty( $settings['button_label'] ) ) : ?>
				<div class="tt-button-wrapper tt-button-primary">
					<a <?php $this->print_render_attribute_string( 'button' ); ?>>
						<span class="tt-btn-content-wrapper">
							<?php if ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon']['value'] ) ) : ?>
								<span <?php $this->print_render_attribute_string( 'icon-align' ); ?>>
									<?php if ( $is_new || $migrated ) :
										Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );
									else : ?>
										<i class="<?php echo esc_attr( $settings['icon'] ); ?>" aria-hidden="true"></i>
									<?php endif; ?>
								</span>
							<?php endif; ?>
							<span <?php $this->print_render_attribute_string( 'button_label' ); ?>><?php $this->print_unescaped_setting( 'button_label' ); ?></span>
						</span>
						<!-- /.tt-btn-content-wrapper -->
					</a>
				</div>
			<?php endif; ?>

			<?php if ( ! empty( $settings['sec_button_label'] ) ) : ?>
				<div class="tt-button-wrapper">
					<?php if ( 'button' == $settings['button_type'] ) : ?>
						<a <?php $this->print_render_attribute_string( 'buttontwo' ); ?>>
							<span class="tt-btn-content-wrapper">
								<?php if ( ! empty( $settings['sec_icon'] ) || ! empty( $settings['sec_selected_icon']['value'] ) ) : ?>
									<span <?php $this->print_render_attribute_string( 'sec_icon_align' ); ?>>
											<?php if ( $is_new || $migrated ) :
												Icons_Manager::render_icon( $settings['sec_selected_icon'], [ 'aria-hidden' => 'true' ] );
											else : ?>
												<i class="<?php echo esc_attr( $settings['sec_icon'] ); ?>" aria-hidden="true"></i>
											<?php endif; ?>
										</span>
								<?php endif; ?>
								<span <?php $this->print_render_attribute_string( 'sec_button_label' ); ?>><?php $this->print_unescaped_setting( 'sec_button_label' ); ?></span>
							</span>
						</a>
					<?php elseif ('popup_video' == $settings['button_type']) : ?>
						<a <?php $this->print_render_attribute_string( 'video' ); ?>>
							<i class="fas fa-play"></i>How It Works
						</a>
					<?php endif; ?>
				</div>
			<?php endif; ?>
		</div>
		<!-- /.tt-btn-wrapper -->
	<?php
	}
}