<?php
/**
 * Portfolio custom post type.
 *
 * @package Haxafy Core
 * @since   1.0.0
 */

// Prevent loading this file directly
defined( 'ABSPATH' ) || exit;

class Portfolio {
	/**
	 * Construct function.
	 *
	 * @return  void
	 */
	function __construct() {
		add_action( 'init', array( __CLASS__, 'portfolio_init' ) );
		add_filter( 'single_template', array( $this, 'portfolio_single' ) );
	}

	/**
	 * Register a Portfolio post type.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/register_post_type
	 */
	public static function portfolio_init() {
		if ( function_exists( 'quiety_option' ) ) {
			$slug_text = quiety_option( 'quiety_portfolio_slug' );
		}

		$slug = ! empty( $slug_text ) ? $slug_text : 'portfolio';

		register_post_type( 'portfolio', array(
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $slug ),
			'capability_type'    => 'post',
			'has_archive'        => false,
			'hierarchical'       => false,
			'menu_position'      => 20,
			'menu_icon'          => 'dashicons-portfolio',
			'supports'           => array( 'title', 'editor', 'thumbnail', 'elementor' ),
			'labels'             => array(
				'name'               => _x( 'Portfolio', 'quiety-core' ),
				'singular_name'      => _x( 'Portfolio', 'quiety-core' ),
				'menu_name'          => _x( 'Portfolio', 'quiety-core' ),
				'name_admin_bar'     => _x( 'Portfolio', 'quiety-core' ),
				'add_new'            => _x( 'Add New', 'quiety-core' ),
				'add_new_item'       => __( 'Add New Portfolio', 'quiety-core' ),
				'new_item'           => __( 'New Portfolio', 'quiety-core' ),
				'edit_item'          => __( 'Edit Portfolio', 'quiety-core' ),
				'view_item'          => __( 'View Portfolio', 'quiety-core' ),
				'all_items'          => __( 'All Portfolios', 'quiety-core' ),
				'search_items'       => __( 'Search Portfolios', 'quiety-core' ),
				'parent_item_colon'  => __( 'Parent Portfolios:', 'quiety-core' ),
				'not_found'          => __( 'No Portfolio found.', 'quiety-core' ),
				'not_found_in_trash' => __( 'No Portfolio found in Trash.', 'quiety-core' )
			),
		) );

		// Register portfolio category
		register_taxonomy( 'portfolio_cat', array( 'portfolio' ), array(
			'hierarchical'      => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'portfolio_cat' ),
			'labels'            => array(
				'name'              => _x( 'Categories', 'quiety-core' ),
				'singular_name'     => _x( 'Category', 'quiety-core' ),
				'search_items'      => __( 'Search Categories', 'quiety-core' ),
				'all_items'         => __( 'All Categories', 'quiety-core' ),
				'parent_item'       => __( 'Parent Category', 'quiety-core' ),
				'parent_item_colon' => __( 'Parent Category:', 'quiety-core' ),
				'edit_item'         => __( 'Edit Category', 'quiety-core' ),
				'update_item'       => __( 'Update Category', 'quiety-core' ),
				'add_new_item'      => __( 'Add New Category', 'quiety-core' ),
				'new_item_name'     => __( 'New Category Name', 'quiety-core' ),
				'menu_name'         => __( 'Categories', 'quiety-core' ),
			),
		) );


		//Register portfolio tag
		register_taxonomy( 'portfolio_tag', 'portfolio', array(
			'hierarchical'          => true,
			'show_ui'               => true,
			'show_admin_column'     => true,
			'update_count_callback' => '_update_post_term_count',
			'query_var'             => true,
			'rewrite'               => array( 'slug' => 'portfolio_tag' ),
			'labels'                => array(
				'name'                       => _x( 'Tags', 'quiety-core' ),
				'singular_name'              => _x( 'Tag', 'quiety-core' ),
				'search_items'               => __( 'Search Tags', 'quiety-core' ),
				'popular_items'              => __( 'Popular Tags', 'quiety-core' ),
				'all_items'                  => __( 'All Tags', 'quiety-core' ),
				'parent_item'                => null,
				'parent_item_colon'          => null,
				'edit_item'                  => __( 'Edit Tag', 'quiety-core' ),
				'update_item'                => __( 'Update Tag', 'quiety-core' ),
				'add_new_item'               => __( 'Add New Tag', 'quiety-core' ),
				'new_item_name'              => __( 'New Tag Name', 'quiety-core' ),
				'separate_items_with_commas' => __( 'Separate tag with commas', 'quiety-core' ),
				'add_or_remove_items'        => __( 'Add or remove tag', 'quiety-core' ),
				'choose_from_most_used'      => __( 'Choose from the most used tag', 'quiety-core' ),
				'not_found'                  => __( 'No tag found.', 'quiety-core' ),
				'menu_name'                  => __( 'Tags', 'quiety-core' ),
			),
		) );
	}

	/**
	 * Load single item template file for the portfolio custom post type.
	 *
	 * @param string $template Current template file.
	 *
	 * @return  string
	 */
	function portfolio_single( $template ) {
		global $post;

		if ( $post->post_type == 'portfolio' ) {
			$template = QUIETY_CORE_DIR . 'inc/post-type/portfolio/views/single.php';
		}

		return $template;
	}


	/**
	 * Define helper function to print related portfolio.
	 *
	 * @return  array
	 */
	public static function related() {

		global $post;
		// Get the good menu tags.
		$cats = get_the_terms( $post, 'portfolio_cat' );

		if ( $cats ) {
			$cat_ids = array();

			foreach ( $cats as $cat ) {
				$cat_ids[] = $cat->term_id;
			}

			$post_perpage = quiety_option( 'relpost_count' ) ? quiety_option( 'relpost_count' ) : (int) '3';

			$args = array(
				'post_type'      => 'portfolio',
				'post__not_in'   => array( $post->ID ),
				'posts_per_page' => $post_perpage,
				'tax_query'      => array(
					array(
						'taxonomy' => 'portfolio_cat',
						'field'    => 'id',
						'terms'    => $cat_ids,
					),
				)
			);

			$the_query = new WP_Query( $args );


			if (  $the_query->have_posts()  ) {
			?>

			<div class="container related-portfolio">
				<?php if ( quiety_option( 'port_title' ) !== '' || quiety_option( 'port_sub_title' ) !== '' ) { ?>
					<div class="section-heading text-center">
						<?php if ( quiety_option( 'port_title' ) !== "" ) : ?>
							<h2 class="section-title"><?php echo esc_html( quiety_option( 'port_title' ) ) ?> </h2>
						<?php endif; ?>
					</div>
				<?php } ?>


				<div class="row justify-content-center">
					<?php while ( $the_query->have_posts() ) : $the_query->the_post(); ?>
						<div class="col-md-4 col-sm-6">
							<div class="quiety-portfolio-item">
								<div class="quiety-portfolio-img">
									<?php if ( has_post_thumbnail() ) : ?>
										<?php the_post_thumbnail('quiety-related-portfolio'); ?>
									<?php endif; ?>

									<div class="quiety-ortfolio-info">
										<h3 class="quiety-portfolio-title"><a href="<?php echo esc_url(the_permalink()); ?>"><?php the_title(); ?></a></h3>

										<?php $terms = get_the_terms( get_the_ID(), 'portfolio_cat' );
										if ( $terms && ! is_wp_error( $terms ) ) :
											foreach ( $terms as $term ) { ?>
												<span class="portfolio-categories"><?php echo $term->name; ?></span>
											<?php } ?>
										<?php endif; ?>
									</div>
								</div>
								<!-- /.quiety-portfolio__post-thumbnail -->
							</div>
							<!-- /.ortfolio-item -->
						</div>
						<!-- /.col-md-4 col-sm-6 -->
					<?php endwhile; ?>
				</div>
				<!-- /.row -->
			</div>
			<!-- /.container -->
		<?php }
		}
		wp_reset_postdata();
	}

	/**
	 * fix paginate not work from page 3
	 *
	 */
	public static function pre_get_posts( $query ) {
		if ( ! is_admin() && $query->is_main_query() ) {
			if ( $query->is_tax( 'quiety_cat' ) || $query->is_tax( 'quiety_tag' ) ) {
				$query->set( 'posts_per_page', cs_get_option( 'portfolio-number-per-page' ) );
			}
		}
	}
}

$portfolio = new Portfolio;